@@ -926,7 +926,8 @@ String& Sheet::getCSV(const char *src_charset, const char *dest_charset, const c
         }
         str = (*this).columns[i];
         trimstr = str.trim();
-        if (str == trimstr && str[0] != '+' && str[0] != '-' && str[0] != '0' &&
+        if (str == trimstr && str[0] != '+' && str[0] != '-' &&
+                (str[0] != '0' || (str[0] == '0' && !isdigit(str[1]))) &&
                 str.searchChar(',') <= 0 && str.searchChar('"') <= 0 &&
                 str.searchChar('\r') <= 0 && str.searchChar('\n') <= 0) {
             *((*this).tmpCSVString) += (*this).columns[i].strconv(src_charset, dest_charset).changeReturnCode(return_str);
@@ -945,7 +946,8 @@ String& Sheet::getCSV(const char *src_charset, const char *dest_charset, const c
             }
             str = (*(*this).pRows[i])[(*this).columns[j]];
             trimstr = str.trim();
-            if (str == trimstr && str[0] != '+' && str[0] != '-' && str[0] != '0' &&
+            if (str == trimstr && str[0] != '+' && str[0] != '-' &&
+                    (str[0] != '0' || (str[0] == '0' && !isdigit(str[1]))) &&
                     str.searchChar(',') <= 0 && str.searchChar('"') <= 0 &&
                     str.searchChar('\r') <= 0 && str.searchChar('\n') <= 0) {
                 *((*this).tmpCSVString) += str.strconv(src_charset, dest_charset).changeReturnCode(return_str);
@@ -977,6 +979,12 @@ bool Sheet::setCSV(const String &csv, const char *src_charset, const char *dest_
 
     (*this).clear();
 
+    if (src_charset == NULL || src_charset[0] == '\0' || !strcasecmp(src_charset, "AUTODETECT")) {
+        src_charset = csv.detectCharSet();
+    } else if (!strcasecmp(src_charset, "AUTODETECT_JP")) {
+        src_charset = csv.detectCharSetJP();
+    }
+
     // Set column names
     pos1 = 0;
     length1 = _searchCSVLineEnd(csv, pos1);
