@@ -49,6 +49,7 @@ namespace apolloron {
     @return void
  */
 Socket::Socket(int recycle_dstSocket) {
+    (*this).dstHost[0] = '\0';
     if (0 <= recycle_dstSocket) {
         (*this).dstSocket = recycle_dstSocket;
         (*this).bConnected = true;
@@ -84,6 +85,7 @@ Socket::~Socket() {
     @retval false failure
  */
 bool Socket::clear() {
+    (*this).dstHost[0] = '\0';
     if ((*this).bConnected) {
         (*this).disconnect();
         (*this).bConnected = false;
@@ -146,6 +148,8 @@ bool Socket::connect(const char *host, const char *port, bool ssl) {
     } else {
         destination = "localhost";
     }
+    strncpy((*this).dstHost, destination, sizeof((*this).dstHost));
+    (*this).dstHost[sizeof((*this).dstHost)-1] = '\0';
 
     timeout.tv_sec = (*this).nTimeout;
     timeout.tv_usec = 0;
@@ -254,7 +258,6 @@ bool Socket::connect(const char *host, const char *port, bool ssl) {
     }
 
     // connect
-    ::setsockopt((*this).dstSocket, SOL_SOCKET, SO_SNDTIMEO, &timeout, sizeof(struct timeval));
     ::setsockopt((*this).dstSocket, SOL_SOCKET, SO_RCVTIMEO, &timeout, sizeof(struct timeval));
 
     if (::connect((*this).dstSocket, (struct sockaddr *) &dstAddr, sizeof(dstAddr)) < 0) {
@@ -291,6 +294,7 @@ bool Socket::connect(const char *host, const char *port, bool ssl) {
         }
 
         SSL_set_fd(pssl, (*this).dstSocket);
+        SSL_set_tlsext_host_name(pssl, (*this).dstHost);
         if (SSL_connect(pssl) <= 0) {
             (*this).nErrno = -1;
             SSL_free(pssl);
@@ -404,6 +408,7 @@ bool Socket::startTls() {
     }
 
     SSL_set_fd(pssl, (*this).dstSocket);
+    SSL_set_tlsext_host_name(pssl, (*this).dstHost);
     if (SSL_connect(pssl) <= 0) {
         (*this).nErrno = -1;
         SSL_free(pssl);
