@@ -155,4 +155,41 @@ const unsigned char cp1252_unicode[EUROPE_UNICODE_TABLE_MAX][2] = {
     {0x00, 0xFC}, {0x00, 0xFD}, {0x00, 0xFE}, {0x00, 0xFF}
 };
 
+
+/* CP1258  0x80-0xFF */
+const unsigned char cp1258_unicode[EUROPE_UNICODE_TABLE_MAX][2] = {
+    {0x20, 0xAC}, {0x00, 0x3F}, {0x20, 0x1A}, {0x01, 0x92},
+    {0x20, 0x1E}, {0x20, 0x26}, {0x20, 0x20}, {0x20, 0x21},
+    {0x02, 0xC6}, {0x20, 0x30}, {0x00, 0x3F}, {0x20, 0x39},
+    {0x01, 0x52}, {0x00, 0x3F}, {0x00, 0x3F}, {0x00, 0x3F},
+    {0x00, 0x3F}, {0x20, 0x18}, {0x20, 0x19}, {0x20, 0x1C},
+    {0x20, 0x1D}, {0x20, 0x22}, {0x20, 0x13}, {0x20, 0x14},
+    {0x02, 0xDC}, {0x21, 0x22}, {0x00, 0x3F}, {0x20, 0x3A},
+    {0x01, 0x53}, {0x00, 0x3F}, {0x00, 0x3F}, {0x01, 0x78},
+    {0x00, 0xA0}, {0x00, 0xA1}, {0x00, 0xA2}, {0x00, 0xA3},
+    {0x00, 0xA4}, {0x00, 0xA5}, {0x00, 0xA6}, {0x00, 0xA7},
+    {0x00, 0xA8}, {0x00, 0xA9}, {0x00, 0xAA}, {0x00, 0xAB},
+    {0x00, 0xAC}, {0x00, 0xAD}, {0x00, 0xAE}, {0x00, 0xAF},
+    {0x00, 0xB0}, {0x00, 0xB1}, {0x00, 0xB2}, {0x00, 0xB3},
+    {0x00, 0xB4}, {0x00, 0xB5}, {0x00, 0xB6}, {0x00, 0xB7},
+    {0x00, 0xB8}, {0x00, 0xB9}, {0x00, 0xBA}, {0x00, 0xBB},
+    {0x00, 0xBC}, {0x00, 0xBD}, {0x00, 0xBE}, {0x00, 0xBF},
+    {0x00, 0xC0}, {0x00, 0xC1}, {0x00, 0xC2}, {0x01, 0x02},
+    {0x00, 0xC4}, {0x00, 0xC5}, {0x00, 0xC6}, {0x00, 0xC7},
+    {0x00, 0xC8}, {0x00, 0xC9}, {0x00, 0xCA}, {0x00, 0xCB},
+    {0x03, 0x00}, {0x00, 0xCD}, {0x00, 0xCE}, {0x00, 0xCF},
+    {0x01, 0x10}, {0x00, 0xD1}, {0x03, 0x09}, {0x00, 0xD3},
+    {0x00, 0xD4}, {0x01, 0xA0}, {0x00, 0xD6}, {0x00, 0xD7},
+    {0x00, 0xD8}, {0x00, 0xD9}, {0x00, 0xDA}, {0x00, 0xDB},
+    {0x00, 0xDC}, {0x01, 0xAF}, {0x03, 0x03}, {0x00, 0xDF},
+    {0x00, 0xE0}, {0x00, 0xE1}, {0x00, 0xE2}, {0x01, 0x03},
+    {0x00, 0xE4}, {0x00, 0xE5}, {0x00, 0xE6}, {0x00, 0xE7},
+    {0x00, 0xE8}, {0x00, 0xE9}, {0x00, 0xEA}, {0x00, 0xEB},
+    {0x03, 0x01}, {0x00, 0xED}, {0x00, 0xEE}, {0x00, 0xEF},
+    {0x01, 0x11}, {0x00, 0xF1}, {0x03, 0x23}, {0x00, 0xF3},
+    {0x00, 0xF4}, {0x01, 0xA1}, {0x00, 0xF6}, {0x00, 0xF7},
+    {0x00, 0xF8}, {0x00, 0xF9}, {0x00, 0xFA}, {0x00, 0xFB},
+    {0x00, 0xFC}, {0x01, 0xB0}, {0x20, 0xAB}, {0x00, 0xFF}
+};
+
 } // namespace apolloron
