@@ -23,6 +23,9 @@ extern const unsigned char cp1251_unicode[EUROPE_UNICODE_TABLE_MAX][2];
 /* CP1252  0x80-0xFF */
 extern const unsigned char cp1252_unicode[EUROPE_UNICODE_TABLE_MAX][2];
 
+/* CP1258  0x80-0xFF */
+extern const unsigned char cp1258_unicode[EUROPE_UNICODE_TABLE_MAX][2];
+
 
 } // namespace apolloron
 #endif
